﻿using System;
using System.Collections.Generic;
using System.Linq;
using com.esendex.sdk.contacts;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace com.esendex.sdk.test.contacts
{
    [TestClass]
    public class ContactTests
    {
        [TestMethod]
        public void Contact_DefaultDIConstructor()
        {
            // Arrange
            string quickname = "quickname";
            string phonenumber = "phonenumber";

            // Act
            Contact contactInstance = new Contact(quickname, phonenumber);

            // Assert
            Assert.AreEqual(quickname, contactInstance.QuickName);
            Assert.AreEqual(phonenumber, contactInstance.PhoneNumber);
            Assert.IsInstanceOfType(contactInstance.Groups, typeof(List<ContactGroupSummary>));
        }

        [TestMethod]
        public void Contact_DefaultDIConstructor_WithNullQuickNameAndMobileNumber_ThrowsException()
        {
            // Arrange
            string quickname = string.Empty;
            string phonenumber = null;

            // Act
            try
            {
                Contact contactInstance = new Contact(quickname, phonenumber);

                Assert.Fail();
            }
            // Assert
            catch (ArgumentNullException ex)
            {
                Assert.AreEqual("quickName", ex.ParamName);
            }
        }

        [TestMethod]
        public void ContactCollection_DefaultConstructor()
        {
            // Arrange

            // Act
            ContactCollection contactCollectionInstance = new ContactCollection();

            // Assert
            Assert.IsInstanceOfType(contactCollectionInstance.Items, typeof(List<Contact>));
        }

        [TestMethod]
        public void ContactCollection_DefaultDIConstructor_WithContact()
        {
            // Arrange
            Contact contact = new Contact();

            // Act
            ContactCollection contactCollectionInstance = new ContactCollection(contact);

            // Assert
            Assert.AreEqual(contact, contactCollectionInstance.Items.ElementAt(0));
        }

        [TestMethod]
        public void ContactCollection_DefaultDIConstructor_WithNullContact_ThrowsArgumentNullException()
        {
            // Arrange
            Contact contact = null;

            // Act
            try
            {
                ContactCollection contactCollectionInstance = new ContactCollection(contact);

                Assert.Fail();
            }
            // Assert
            catch (ArgumentNullException ex)
            {
                Assert.AreEqual("contact", ex.ParamName);
            }
        }

        [TestMethod]
        public void ContactCollection_DefaultDIConstructor_WithContactsArray()
        {
            // Arrange
            Contact contact = new Contact();

            List<Contact> contacts = new List<Contact>();

            contacts.Add(contact);

            // Act
            ContactCollection contactCollectionInstance = new ContactCollection(contacts);

            // Assert
            Assert.AreEqual(contact, contactCollectionInstance.Items.ElementAt(0));
        }

        [TestMethod]
        public void ContactCollection_DefaultDIConstructor_WithNullContactArray_ThrowsArgumentNullException()
        {
            // Arrange
            List<Contact> contacts = null;

            // Act
            try
            {
                ContactCollection contactCollectionInstance = new ContactCollection(contacts);

                Assert.Fail();
            }
            // Assert
            catch (ArgumentNullException ex)
            {
                Assert.AreEqual("contacts", ex.ParamName);
            }
        }
    }
}